@@ -28,7 +28,6 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 #include <util.h>
-RCSID("$Id: gas-parse.c 2279 2010-01-19 07:57:43Z peter $");
 
 #include <libyasm.h>
 
@@ -906,7 +905,6 @@ parse_instr(yasm_parser_gas *parser_gas)
 {
     yasm_bytecode *bc;
     char *id;
-    size_t id_len;
     uintptr_t prefix;
 
     if (parser_gas->intel_syntax) {
@@ -926,7 +924,6 @@ parse_instr(yasm_parser_gas *parser_gas)
         return NULL;
 
     id = ID_val;
-    id_len = ID_len;
 
     /* instructions/prefixes must start with a letter */
     if (!isalpha(id[0]))
